@@ -10,9 +10,12 @@ if __name__ == '__main__':
     configuration.sk = "SK"
     configuration.region = "cn-beijing"
     configuration.client_side_validation = True
+    # set default configuration
+    volcenginesdkcore.Configuration.set_default(configuration)
+
+    api_instance = volcenginesdkautoscaling.AUTOSCALINGApi()
 
     try:
-        api_instance = volcenginesdkautoscaling.AUTOSCALINGApi(volcenginesdkcore.ApiClient(configuration))
         resp = api_instance.describe_scaling_groups(volcenginesdkautoscaling.DescribeScalingGroupsRequest(
             _configuration=configuration
         ))
